# Github-Agent (GHAgent)

# TODO
- [ ] Create a LICENSE

# Development Setup
1. Install [pipx](https://github.com/pypa/pipx)
2. Install [poetry](https://python-poetry.org/docs/)
3. Install dependencies
    ```
    cd ghagent
    poetry install
    ```
4. Run
   ```
   # poetry run gha <supported commands, e.g. init, config, run...>

   # config
   poetry run gha config ...

   # run
   poetry run gha run litanlitudan/skyagi
   ```
